MethodChannelFlutterPlugin class

An implementation of FlutterPluginPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

firebaseToken(String value) → Future<void>
Sends a Firebase token with the specified value.
getPlatformVersion() → Future<String?>
override
initializeSDK() → Future<void>
Initializes the Mergn SDK.
login(String value) → Future<void>
Logs in with the specified value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerAPICall(String apiKey) → Future<void>
Registers an API call with the provided apiKey.
sendAttribute(String attributeName, String attributeValue) → Future<void>
Sends an attribute with the specified attributeName and attributeValue.
sendEvent(String eventName, Map<String, String> eventProperties) → Future<void>
Sends an event with the specified eventName and eventProperties.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited